"""
This package contains the basic jit widgets.

Get this source from http://github.com/toscawidgets/tw2.jit
"""

#TODO -- this is *not* the right way to do this.
jit_base = "static/Jit-2.0.1"

from widgets import (
    AreaChart,
    BarChart,
    PieChart,
    TreeMap,
    ForceDirectedGraph,
    RadialGraph,
    Sunburst,
    Icicle,
    SpaceTree,
    HyperTree,
)

from widgets import AjaxRadialGraph

from widgets import SQLARadialGraph
